@@ -35,7 +35,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL.php,v 1.16 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL.php,v 1.17 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -43,7 +43,7 @@
 /**
  * С
  */
-define('SYL_VERSION', '0.8.6');
+define('SYL_VERSION', '0.9.0');
 
 /**
  * ١ǥ쥯ȥ
@@ -51,15 +51,6 @@ define('SYL_VERSION', '0.8.6');
 define('SYL_DIR', dirname(__FILE__));
 define('SYL_INCLUDE_DIR', SYL_DIR . '/include');
 
-/**
- * PHPƥ२顼¸ե饰
- */
-define('SYL_LOG_SYSTEM_ERROR', true);
-/**
- * PHPƥ२顼¸ե
- */
-define('SYL_LOG_SYSTEM_ERROR_FILE', SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log');
-
 /**
  * ǥХå٥
  */
@@ -78,10 +69,20 @@ define('SYL_ENCODE_MAIL',     'ISO-2022-JP');
 define('SYL_ENCODE_AJAX',     'UTF-8');
 define('SYL_ENCODE_XML',      'UTF-8');
 
-/*
-DIRECTORY_SEPARATOR
-PATH_SEPARATOR (4 >= 4.3.0-RC2)
-*/
+// PHP 5.1ʾѥॾ
+if (version_compare(PHP_VERSION, '5.1.0', '>=') && !ini_get('date.timezone')) {
+    date_default_timezone_set('Asia/Tokyo');
+}
+
+/**
+ * PHPƥ२顼¸ե饰
+ */
+define('SYL_LOG_SYSTEM_ERROR', true);
+/**
+ * PHPƥ२顼¸ե
+ */
+define('SYL_LOG_SYSTEM_ERROR_FILE', SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log');
+
 
 // ȥɤ߹
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Controller.php';
