@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.13 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.13 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -116,7 +116,7 @@ class SyL_ConfigActions extends SyL_Config
      *
      * @access public
      */
-    function parseXML()
+    function parseXml()
     {
         if (SYL_WEBAPP_CACHE_DIR) {
             // åѤ
@@ -125,7 +125,7 @@ class SyL_ConfigActions extends SyL_Config
             $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/actions');
             $this->config = $cache->read($this->file_names);
             if (!$this->config) {
-                parent::parseXML();
+                parent::parseXml();
                 // åѥ᡼¸
                 $this->config[$this->action_cache_key] = $this->action_cache_value;
                 $cache->write($this->config);
@@ -137,7 +137,7 @@ class SyL_ConfigActions extends SyL_Config
             unset($this->config[$this->action_cache_key]);
         } else {
             // åѤʤ
-            parent::parseXML();
+            parent::parseXml();
         }
 
         $this->dm->setTemplateFile($this->action_cache_value['template']);
@@ -152,6 +152,10 @@ class SyL_ConfigActions extends SyL_Config
                 $this->dm->cm->addAppComponent($name, $value[0], $value[1]);
             }
         }
+
+        if (!isset($this->config['action'])) {
+            trigger_error("[SyL error] Action mapping not found (" . $this->dm->getActionFile() . ")", E_USER_ERROR);
+        }
     }
 
 /*
