@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_LoggerFile.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerConsole.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerConsole extends SyL_LoggerFile
@@ -69,8 +69,8 @@ class SyL_LoggerConsole extends SyL_LoggerFile
     function open()
     {
         if ($this->writer == null) {
-            $this->writer = new SyL_FileWriter('php://stdout');
-            $this->writer->open('w');
+            $this->writer =& SyL_File::getObject('writer', 'php://stdout');
+            $this->writer->open();
         }
     }
 
