@@ -27,15 +27,15 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ե񤭹ߥ饹
+ * ե륯饹
  */
-require_once SYL_INCLUDE_DIR . '/lib/SyL_FileWriter.php';
+require_once SYL_INCLUDE_DIR . '/lib/SyL_File.php';
 
 /**
  * եؤΥϥ饹
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_FileWriter.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.10 2007/02/25 14:20:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerFile extends SyL_Logger
@@ -81,7 +81,7 @@ class SyL_LoggerFile extends SyL_Logger
         $filename = str_replace('DD',   date('d'), $filename);
 
         if ($this->writer == null) {
-            $this->writer = new SyL_FileWriter($filename);
+            $this->writer =& SyL_File::getObject('writer', $filename);
             $this->writer->open('ab');
         }
     }
