@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.10 2007/01/28 07:13:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -62,7 +62,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.10 2007/01/28 07:13:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo2 extends SyL_Router
@@ -104,9 +104,16 @@ class SyL_RouterPathinfo2 extends SyL_Router
             $pathinfo_file  = basename($pathinfo);
             $pathinfo_dir   = dirname($pathinfo);
             $pathinfo_files = explode($this->action_delimiter, $pathinfo_file, 2);
+
+            // windowsб
+            if ($pathinfo_dir == '\\') {
+                $pathinfo_dir = '';
+            }
+
             if ($pathinfo_dir != '/') {
                 $pathinfo_dir = $pathinfo_dir . '/';
             }
+
             if (count($pathinfo_files) == 2) {
                 if (($this->action_delimiter == '.') && ($this->url_ext == ('.' . $pathinfo_files[1]))) {
                     // ʤ
