@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.13 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.13 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -321,7 +321,7 @@ echo "</pre>";
         $config = array();
         foreach ($config_type as $type => $file) {
             $reader =& SyL_Config::getObject($type, $file, $this->getComponent(SYL_CONTROLLER_NAME), $event);
-            $reader->parseXML();
+            $reader->parseXml();
             $config += $reader->getConfig();
         }
         return $config;
