@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.17 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.18 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -75,7 +75,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.17 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.18 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -212,7 +212,7 @@ class SyL_Controller
         static $singleton;
         if (!is_object($singleton)) {
             if (isset($config['type']) && $config['type']) {
-                define('SYL_ENV_TYPE', $config['type']);
+                define('SYL_ENV_TYPE', strtolower($config['type']));
             } else {
                 if ((PHP_SAPI == 'cli') || ((PHP_SAPI == 'cgi') && !isset($_SERVER['REQUEST_METHOD']))) {
                     define('SYL_ENV_TYPE', 'cmd');
