@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Filter.php,v 1.11 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Filter.php,v 1.12 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,20 +39,59 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Filter.php,v 1.11 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Filter.php,v 1.12 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  **/
 class SyL_Filter
 {
     /**
-     * 쥯ȼ᥽å
+     * ¹ե륿᥽å
+     *
+     * @access public
+     * @param object ꥯȥ֥
+     */
+    function preAction(&$request)
+    {
+    }
+
+    /**
+     * ¹Ըե륿᥽å
+     *
+     * @access public
+     * @param object ǡޥ͡㥪֥
+     */
+    function postAction(&$dm)
+    {
+    }
+
+    /**
+     * ե륿᥽å
+     *
+     * @access public
+     * @param object ӥ塼֥
+     */
+    function preRender(&$view)
+    {
+    }
+
+    /**
+     * ϸե륿᥽å
+     *
+     * @access public
+     */
+    function postRender()
+    {
+    }
+
+    /**
+     * 쥯ȥ᥽å
      *
      * @access public
      */
     function trigger()
     {
+        return null;
     }
-
 }
 
 ?>
