@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.8 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.9 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.8 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.9 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -77,9 +77,12 @@ class SyL_Response
      */
     function redirect($url)
     {
-        SyL_Response::setHeader('Location', $url);
-        $obj =& SyL_Response::getInstance();
-        $obj->sendHeader();
+        if (SYL_ENV_TYPE == 'web') {
+            SyL_Loggers::debug("[Response] Redirect -> {$url}");
+            SyL_Response::setHeader('Location', $url);
+            $obj =& SyL_Response::getInstance();
+            $obj->sendHeader();
+        }
         exit;
     }
 
@@ -91,16 +94,17 @@ class SyL_Response
      */
     function redirect404()
     {
-        $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';
-        SyL_Loggers::info("[Response] 404 Not Found - {$request_uri}");
-
         SyL_Response::setStatusHeader('404');
-        if (SYL_ERROR_URL_404) {
-            SyL_Response::redirect(SYL_ERROR_URL_404);
-        } else {
-            echo "<h2>HTTP/1.0 404 Not Found</h2>";
-            exit;
+        if (SYL_ENV_TYPE == 'web') {
+            $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';
+            SyL_Loggers::info("[Response] 404 Not Found - {$request_uri}");
+            if (SYL_ERROR_URL_404) {
+                SyL_Response::redirect(SYL_ERROR_URL_404);
+            } else {
+                echo "<h2>HTTP/1.0 404 Not Found</h2>";
+            }
         }
+        exit;
     }
 
     /**
@@ -225,35 +229,32 @@ class SyL_Response
      * 󥰤줿HTML
      * 
      * @access public
-     * @param mixed ӥ塼֥ȡޤɽǡ
+     * @param object ӥ塼֥
      */
     function display(&$view)
     {
-        $data           = '';
-        $content_type   = '';
-        $content_length = false;
-        $gzip_compress  = false;
         if (is_object($view)) {
             $data           =& $view->getRender();
             $content_type   =  $view->getContentType();
             $content_length =  $view->isContentLength();
             $gzip_compress  =  $view->isGzipCompress();
-        } else {
-            $data = $view;
-        }
 
-        // ƥĥפ򥻥å
-        if ($content_type) {
-            SyL_Response::setHeader('Content-Type', $content_type);
-        }
-
-        // gzip̤ѲǽʤѤ
-        if (!$gzip_compress || !$this->convertGzip($data)) {
-            // gzip̤ʤ硢ƥ̤򥻥å
-            if ($content_length) {
-                SyL_Response::setHeader('Content-Length', strlen($data));
+            // ƥĥפ򥻥å
+            if ($content_type) {
+                SyL_Response::setHeader('Content-Type', $content_type);
             }
+
+            // gzip̤ѲǽʤѤ
+            if (!$gzip_compress || !$this->convertGzip($data)) {
+                // gzip̤ʤ硢ƥ̤򥻥å
+                if ($content_length) {
+                    SyL_Response::setHeader('Content-Length', strlen($data));
+                }
+            }
+        } else {
+            $data =& $view;
         }
+
         // إå
         $this->sendHeader();
         // ɽǡ
@@ -266,7 +267,7 @@ class SyL_Response
         }
 
         // 
-        $view->clearRender();
+        $data = null;
     }
 
     /**
@@ -326,7 +327,7 @@ class SyL_Response
         default   : return false;
         }
 
-        return "HTTP/{$http_version} {$message}";
+        return "HTTP/{$http_version} {$status_code} {$message}";
     }
 }
 
